# bstats

bStats Metrics for Endstone Plugins

## Features

- [ ] Metrics Class
- Custom Charts
    - [x] Simple Pie
    - [x] Advanced Pie
    - [ ] Drilldown Pie
    - [ ] Single Line
    - [ ] Multi Line
    - [ ] Simple Bar
    - [ ] Advanced Bar